@@ -1,8 +1,9 @@
 /*****************************************************************************
- * Secure Locate v2.3                                                        *
- * September 8, 2000                                                         *
+ * Secure Locate v2.4                                                        *
+ * November 28, 2000                                                         *
  * Programmed by: Kevin Lindsay                                              *
- * Copyright (c) 1999, 2000 Kevin Lindsay & Netnation Communications Inc.    *
+ * Copyright (c) 1994, 1999, 2000 Kevin Lindsay & Netnation Communications,  *
+ *                                Inc. & Free Software Foundation, Inc.      *
  *                                                                           *
  * NetNation Communications   http://www.netnation.com/                      *
  * Secure Locate: ftp://ftp.linux-geek.org/slocate/                          *
@@ -53,8 +54,6 @@
  *                  showing files that the user using slocate does not have   
  *                  access to.                                                
  *                                                                            
- *    Copyright (C) 1994 Free Software Foundation, Inc.                       
- *                                                                            
  *    This program is free software; you can redistribute it and/or modify    
  *    it under the terms of the GNU General Public License as published by    
  *    the Free Software Foundation; either version 2, or (at your option)     
@@ -84,7 +83,8 @@
 #include <ctype.h>
 #include <fnmatch.h>
 #include <regex.h>
-#include "sl_fts.h"
+#include <fts.h>
+//#include "sl_fts.h"
 
 #include "link.h"
 #include "misc.h"
@@ -98,7 +98,7 @@
 
 /* GLOBALS */
 
-#define VERSION "Secure Locate v2.3 - Released September 8, 2000\n"
+#define VERSION "Secure Locate v2.4 - Released November 28, 2000\n"
 #define GRPFILE "/etc/group"
 #define SLOC_ESC 0x80
 #define SLOC_GRP "slocate"
@@ -157,7 +157,8 @@ void
 {
 	int i;
 	printf("%s\n"
-	       "Copyright (c) 1999, 2000 Kevin Lindsay & Netnation Communications Inc.\n\n"
+	       "Copyright (c) 1994, 1999, 2000 Kevin Lindsay & Netnation Communications Inc. &\n"
+	       "                               Free Software Foundation, Inc.\n\n"
 	       "search usage:   %s [-qi] [-d <path>] [--database=<path>] <search string>...\n"
 	       "                %s [-r <regexp>] [--regexp=<regexp>]\n"
 	       "database usage: %s [-qv] [-o <file>] [--output=<file>]\n"
